@@ -489,6 +489,17 @@ directory_root_info_new (GFile                 *file,
 		allow_stat = FALSE;
 	}
 
+	/* NOTE: GFileInfo is ABSOLUTELY required here, without it the
+	 * TrackerFileNotifier will think that top level roots have
+	 * been deleted because the GFileInfo GQuark does not exist.
+	 *
+	 * This is seen easily by mounting a removable device,
+	 * indexing, then removing, then re-inserting that same
+	 * device.
+	 *
+	 * The check is done later in the TrackerFileNotifier by
+	 * looking up the qdata that we set in both conditions below.
+	 */
 	if (allow_stat && file_attributes) {
 		GFileInfo *file_info;
 		GFileQueryInfoFlags file_flags;
@@ -504,6 +515,30 @@ directory_root_info_new (GFile                 *file,
 		                         file_info_quark,
 		                         file_info,
 		                         (GDestroyNotify) g_object_unref);
+	} else {
+		GFileInfo *file_info;
+		gchar *basename;
+
+		file_info = g_file_info_new ();
+		g_file_info_set_file_type (file_info, G_FILE_TYPE_DIRECTORY);
+
+		basename = g_file_get_basename (file);
+		g_file_info_set_name (file_info, basename);
+		g_free (basename);
+
+		/* Only thing missing is mtime, we can't know this.
+		 * Not setting it means 0 is assumed, but if we set it
+		 * to 'now' then the state machines above us will
+		 * assume the directory is always newer when it may
+		 * not be.
+		 */
+
+		g_file_info_set_content_type (file_info, "inode/directory");
+
+		g_object_set_qdata_full (G_OBJECT (file),
+		                         file_info_quark,
+		                         file_info,
+		                         (GDestroyNotify) g_object_unref);
 	}
 
 	/* Fill in the processing info for the root node */
@@ -729,7 +764,7 @@ data_provider_data_process (DataProviderData *dpd)
 		children = g_list_prepend (children, child_data->child);
 	}
 
-	g_signal_emit (crawler, signals[CHECK_DIRECTORY_CONTENTS], 0, dpd->dir_info->node->data, children, &use);
+	g_signal_emit (crawler, signals[CHECK_DIRECTORY_CONTENTS], 0, dpd->dir_file, children, &use);
 	g_list_free (children);
 
 	if (!use) {
@@ -747,7 +782,7 @@ data_provider_data_add (DataProviderData *dpd)
 	GSList *l;
 
 	crawler = dpd->crawler;
-	parent = dpd->dir_info->node->data;
+	parent = dpd->dir_file;
 
 	for (l = dpd->files; l; l = l->next) {
 		GFileInfo *info;
@@ -818,11 +853,9 @@ data_provider_end_cb (GObject      *object,
 
 	if (error) {
 		if (!cancelled) {
-			GFile *parent;
 			gchar *uri;
 
-			parent = dpd->dir_info->node->data;
-			uri = g_file_get_uri (parent);
+			uri = g_file_get_uri (dpd->dir_file);
 
 			g_warning ("Could not end data provider for container / directory '%s', %s",
 			           uri, error ? error->message : "no error given");
@@ -912,12 +945,10 @@ enumerate_next_cb (GObject      *object,
 			/* condition a) */
 
 			if (!cancelled) {
-				GFile *parent;
 				gchar *uri;
 
 				/* condition b) */
-				parent = dpd->dir_info->node->data;
-				uri = g_file_get_uri (parent);
+				uri = g_file_get_uri (dpd->dir_file);
 				g_warning ("Could not enumerate next item in container / directory '%s', %s",
 				           uri, error ? error->message : "no error given");
 				g_free (uri);
@@ -963,11 +994,9 @@ data_provider_begin_cb (GObject      *object,
 
 	if (!dpd->enumerator) {
 		if (error && !cancelled) {
-			GFile *parent;
 			gchar *uri;
 
-			parent = dpd->dir_info->node->data;
-			uri = g_file_get_uri (parent);
+			uri = g_file_get_uri (dpd->dir_file);
 
 			g_warning ("Could not enumerate container / directory '%s', %s",
 			           uri, error ? error->message : "no error given");
